<?php

namespace App\Http\Controllers;

use App\Payment;
use App\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Http;

class PaymentController extends Controller
{

    public function payment(Request $request)
    {
        $rules = [
            'fullname' => 'required',
            'amount' => 'required|between:1100,2000000000|numeric',
            'description' => 'required|max:250',
            'email' => 'email',
            'mobile' => 'numeric|digits:11'

        ];
        $customMessages = [
            'required' => 'ورودی نباید خالی باشد',
            'numeric' => 'بصورت عددی وارد کنید',
            'max' => 'توضیحات ماکزیمم ۲۵۰ کاراکتر میتواند باشد',
            'email' => 'آدرس ایمیل معتبر وارد کنید',
            'digits' => 'شماره تلفن همراه معتبر وارد کنید',
            'amount.between' => 'مبلغ باید بین 1100 تومان و 200 میلیون تومان و بصورت عددی وارد شود'

        ];
        $this->validate($request, $rules, $customMessages);

        $merchantcodes = DB::table('merchants')->latest()->first();

        $merchantId = $merchantcodes->merchantCode;
        $name = $request->input('fullname');
        $amountValue = (int)$request->input('amount');
        $mobile = $request->mobile;
        $email = $request->email;
        $description = $request->description;


        $user = new User();
        $user->fullname = $name;
        $user->email = $email;
        $user->mobile = $mobile;
        $user->save();


        $payment = new Payment();
//        $payment->Authority = $result['data']["authority"];
        $payment->Amount = $amountValue;
//        $payment->refid = $result['data']["authority"];
        $payment->Description = $description;
        $payment->user_id = $user->id;
        $payment->status = "Created";
        $payment->save();

//        dd($payment->id);
        $data = [
            "merchant_id" => "{$merchantId}",
            "amount" => $amountValue,
            "callback_url" => route('payment.callback', ['order_id' => $payment->id]),
            "callback_method" => "GET",
            "invoice_id" => "order_{$payment->id}",
            "description" => "{$description}",
            "email" => "{$email}",
            "mobile" => "{$mobile}",
            "name" => "{$name}"
        ];

        try {
            $resp = Http::withoutVerifying()
                ->post('https://api.novinopay.com/payment/ipg/v2/request', $data)
                ->object();

            if ($resp->status == 100) {
                $payment->update([
                    'Authority' => $resp->data->authority,
                    'status' => 'SendForPayment'
                ]);
                return redirect()->away($resp->data->payment_url);
            } else {

                echo "<div style='font-size: xx-large; color: darkred; background-color: rgba(255,113,79,0.67);text-align: center;'> {$resp->message} </div>";

            }
        } catch (\Throwable $e) {
            echo "<div style='font-size: xx-large; color: darkred; background-color: rgba(255,113,79,0.67);text-align: center;'> امکان اتصال به درگاه وجود ندارد </div>";
        }
    }

    public function verifypayment(Request $request, $order_id)
    {

        $merchantcodes = DB::table('merchants')->latest()->first();
        $merchantId = $merchantcodes->merchantCode;

        $payment = Payment::where('id', '=', $order_id)->first();
        if (is_null($payment)) {
            echo "<div style='font-size: xx-large; color: darkred; background-color: rgba(255,113,79,0.67);text-align: center;'> تراکنش یافت نشد </div>";
            die;
        }

        if ($payment->Status == 'SendForPayment') {
            if ($payment->Authority == $request->Authority && $request->PaymentStatus == 'OK') {
                $data = [
                    "merchant_id" => "{$merchantId}",
                    "amount" => "{$payment->Amount}",
                    "authority" => "{$payment->Authority}",
                ];
                try {
                    $resp = Http::withoutVerifying()
                        ->post('https://api.novinopay.com/payment/ipg/v2/verification', $data)
                        ->object();

                    if ($resp->status == 100 || $resp->status == 101) {
                        $payment->update([
                            'refid' => $resp->data->ref_id,
                            'status' => 'success'
                        ]);
                        echo "<div style='font-size: xx-large; color: #278b00; background-color: rgba(141,255,79,0.67);text-align: center;'> تراکنش با موفقیت انجام شد. کد پیگیری: {$payment->refid} </div>";
                        die;
                    } else {
                        echo "<div style='font-size: xx-large; color: darkred; background-color: rgba(255,113,79,0.67);text-align: center;'> {$resp->message} </div>";
                        die;
                    }

                } catch (\Throwable $e) {
                    dd($e->getMessage());
                    echo "<div style='font-size: xx-large; color: darkred; background-color: rgba(255,113,79,0.67);text-align: center;'> بروز خطا در تایید تراکنش </div>";
                    die;
                }
            } else if ($request->PaymentStatus == 'NOK') {
                $payment->update([
                    'status' => 'failed'
                ]);
                echo "<div style='font-size: xx-large; color: darkred; background-color: rgba(255,113,79,0.67);text-align: center;'> تراکنش ناموفق بود </div>";
                die;
            }
        } else if ($payment->Status == 'success') {
            echo "<div style='font-size: xx-large; color: #278b00; background-color: rgba(141,255,79,0.67);text-align: center;'> تراکنش با موفقیت انجام شد. کد پیگیری: {$payment->refid} </div>";
            die;
        } else if ($payment->Status == 'failed') {
            echo "<div style='font-size: xx-large; color: darkred; background-color: rgba(255,113,79,0.67);text-align: center;'> تراکنش ناموفق بود </div>";
            die;
        } else {
            dd('امکان تایید تراکنش وجود ندارد.');
        }


    }
}
